import java.util.concurrent.CyclicBarrier;

import org.hornetq.api.core.HornetQException;
import org.hornetq.api.core.TransportConfiguration;
import org.hornetq.api.core.client.ClientMessage;
import org.hornetq.api.core.client.ClientProducer;
import org.hornetq.api.core.client.ClientSession;
import org.hornetq.api.core.client.ClientSessionFactory;
import org.hornetq.api.core.client.HornetQClient;
import org.hornetq.core.remoting.impl.invm.InVMConnectorFactory;

public class TestProducer implements Runnable {

	private int count;
	private final String queueName;
	private final CyclicBarrier cb;


	public TestProducer(String queueName, int count, CyclicBarrier cb) {
		this.queueName = queueName;
		this.count = count;
		this.cb = cb;
	}

	@Override
	public void run() {
		ClientSessionFactory sf = HornetQClient
			.createClientSessionFactory(new TransportConfiguration(
				InVMConnectorFactory.class.getName()));

		ClientSession session = null;

		try {
			// Step 5. Create the session, and producer
			session = sf.createSession();
			ClientProducer producer = session.createProducer(queueName);
			// Step 6. Create and send a message
			long time = System.currentTimeMillis();
			for (int msgIndex = 0; msgIndex < count; msgIndex++) {
				String text = "Message#" + msgIndex;

				ClientMessage message = session.createMessage(true);
				final String propName = "myprop";
				message.putStringProperty(propName, text);
				//				message.putObjectProperty(arg0, arg1)
				System.out.println(Thread.currentThread().getName() + " send:"
					+ text);
				producer.send(message);
			}
			time = System.currentTimeMillis() - time;
			System.out.println(Thread.currentThread().getName()
				+ " time to send [" + count + "] messages : " + time + " ms"
				+ "\r\n" + (count * 1000 / time) + " messages per second");
		} catch (Exception ex) {
			ex.printStackTrace();
		} finally {
			if (session != null) {
				try {
					session.close();
				} catch (HornetQException e) {
					e.printStackTrace(); //To change body of catch statement use File | Settings | File Templates.
				}
			}
			try {
				cb.await();
			} catch (Exception e) {
				throw new RuntimeException(e);
			}
		}

	}

}